setuptools_scm: Python build system extension to obtain package version from version control
============================================================================================

Description
-----------

the blessed package to manage your versions by scm tags

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/setuptools-scm/

